@@ -12,42 +12,41 @@ Reference:
     Neural Computation 11, 1621-1671 (1999)
 """
 
-from brian import *
+from brian2 import *
 
 N = 5000
-Vr = 10 * mV
-theta = 20 * mV
-tau = 20 * ms
-delta = 2 * ms
-taurefr = 2 * ms
-duration = .1 * second
+Vr = 10*mV
+theta = 20*mV
+tau = 20*ms
+delta = 2*ms
+taurefr = 2*ms
+duration = .1*second
 C = 1000
 sparseness = float(C)/N
-J = .1 * mV
-muext = 25 * mV
-sigmaext = 1 * mV
+J = .1*mV
+muext = 25*mV
+sigmaext = 1*mV
 
 eqs = """
 dV/dt = (-V+muext + sigmaext * sqrt(tau) * xi)/tau : volt
 """
 
-group = NeuronGroup(N, eqs, threshold=theta,
-                    reset=Vr, refractory=taurefr)
+group = NeuronGroup(N, eqs, threshold='V>theta',
+                    reset='V=Vr', refractory=taurefr, method='euler')
 group.V = Vr
-conn = Connection(group, group, state='V', delay=delta,
-                  weight = -J,
-                  sparseness=sparseness)
+conn = Synapses(group, group, on_pre='V += -J', delay=delta)
+conn.connect(p=sparseness)
 M = SpikeMonitor(group)
-LFP = PopulationRateMonitor(group, bin=0.4 * ms)
+LFP = PopulationRateMonitor(group)
 
 run(duration)
 
 subplot(211)
-raster_plot(M)
+plot(M.t/ms, M.i, '.')
 xlim(0, duration/ms)
 
 subplot(212)
-plot(LFP.times_/ms, LFP.rate)
+plot(LFP.t/ms, LFP.smooth_rate(window='flat', width=0.5*ms)/Hz)
 xlim(0, duration/ms)
 
 show()
